==> haskell-hasql-transaction-0.5-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-transaction
version: 0.5
id: hasql-transaction-0.5-AO8j4qUzoJA9Wxek6NSOcv
key: hasql-transaction-0.5-AO8j4qUzoJA9Wxek6NSOcv
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-transaction
synopsis: A composable abstraction over the retryable transactions for Hasql
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules: Hasql.Transaction.Private.Prelude
                Hasql.Transaction.Private.Model Hasql.Transaction.Private.SQL
                Hasql.Transaction.Private.Queries
                Hasql.Transaction.Private.Sessions
                Hasql.Transaction.Private.Transaction
abi: 13c442d832a5ecbafa0f737bc98f8f2b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hasql-transaction-0.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/hasql-transaction-0.5
data-dir: /usr/share/arm-linux-ghc-8.0.1/hasql-transaction-0.5
hs-libraries: HShasql-transaction-0.5-AO8j4qUzoJA9Wxek6NSOcv
depends:
    base-4.9.0.0 base-prelude-1.2.0.1-fuY5fEKAmeDVnWLCVSGcQ
    bytestring-0.10.8.1
    bytestring-tree-builder-0.2.7.1-DhaA5xRjPyvKyuwLLQ86nC
    contravariant-1.4-KgMYVwXYQBGKuyyJtYdP11
    contravariant-extras-0.3.3.1-6AvuWK4Qahw4D6uBR5fRq7
    hasql-0.19.18-AXRFgtx8SOBLLbwD0ekFL6
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock
haddock-html: /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-transaction-0.5-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-transaction
version: 0.5
id: hasql-transaction-0.5-5ek6ggtecUVVC6qusxzKP
key: hasql-transaction-0.5-5ek6ggtecUVVC6qusxzKP
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-transaction
synopsis: A composable abstraction over the retryable transactions for Hasql
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules: Hasql.Transaction.Private.Prelude
                Hasql.Transaction.Private.Model Hasql.Transaction.Private.SQL
                Hasql.Transaction.Private.Queries
                Hasql.Transaction.Private.Sessions
                Hasql.Transaction.Private.Transaction
abi: 1d40cb9772f348cdd0ab5a36cff974a9
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hasql-transaction-0.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/hasql-transaction-0.5
data-dir: /usr/share/arm-linux-ghc-8.0.1/hasql-transaction-0.5
hs-libraries: HShasql-transaction-0.5-5ek6ggtecUVVC6qusxzKP
depends:
    base-4.9.0.0 base-prelude-1.2.0.1-fuY5fEKAmeDVnWLCVSGcQ
    bytestring-0.10.8.1
    bytestring-tree-builder-0.2.7.1-DhaA5xRjPyvKyuwLLQ86nC
    contravariant-1.4-KgMYVwXYQBGKuyyJtYdP11
    contravariant-extras-0.3.3.1-6AvuWK4Qahw4D6uBR5fRq7
    hasql-0.19.18-5T26uhx6UxUFHMBh0eqOvn
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock
haddock-html: /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
